Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var DecryptionFailedError error = &SteamAppTicketError{Message: "Failed to decrypt ticket"}
var InvalidSignatureError error = &SteamAppTicketError{Message: "Missing or Invalid Signature"}
var InvalidTicketError error = &SteamAppTicketError{Message: "Invalid ticket"}
var SteamPublicKey, _ = pem.Decode([]byte(
`-----BEGIN PUBLIC KEY-----
MIGdMA0GCSqGSIb3DQEBAQUAA4GLADCBhwKBgQDf7BrWLBBmLBc1OhSwfFkRf53T
2Ct64+AVzRkeRuh7h3SiGEYxqQMUeYKO6UWiSRKpI2hzic9pobFhRr3Bvr/WARvY
gdTckPv+T1JzZsuVcNfFjrocejN1oWI0Rrtgt4Bo+hOneoo3S57G9F1fOpn5nsQ6
6WOiu4gZKODnFMBCiQIBEQ==
-----END PUBLIC KEY-----`))
Functions ¶
This section is empty.
Types ¶
type DLCDetails ¶
type SteamAppTicket ¶
type SteamAppTicket struct {
SteamID uint64 // The Steam ID of the user who owns the ticket.
AuthTicket []byte // The raw authentication ticket for the app.
GCToken uint64 // The game connect token for the app.
GCTokenGenerated time.Time // The time when the ticket was generated.
SessionExternalIP net.IP // The external IP address of the user's session.
ClientConnectionTime uint32 // The time when the client connected to the server.
ClientConnectionCount uint32 // The number of times the client has connected to the server.
Version uint32 // The version of the app.
AppID uint32 // The game's Steam App ID.
OwnershipTicketExternalIP net.IP // The external IP address of the user's ownership ticket.
OwnershipTicketInternalIP net.IP // The internal IP address of the user's ownership ticket.
OwnershipFlags uint32 // Flags associated with the ownership ticket.
OwnershipTicketGenerated time.Time // The time when the ownership ticket was generated.
OwnershipTicketExpires time.Time // The time when the ownership ticket expires.
Licenses []uint32 // A list of the user's licenses for the app.
DLC []DLCDetails // A list of details about the DLCs which the account holds.
Signature []byte // The signature of the ticket.
IsExpired bool // Indicates whether the ticket has expired.
HasValidSignature bool // Indicates whether the ticket has a valid signature.
IsValid bool // Indicates whether the ticket is valid (neither expired nor with an invalid signature).
UserData []byte // Additional user data associated with the ticket, created when requesting the ticket.
}
func ParseAppTicket ¶
func ParseAppTicket(ticket []byte, allowInvalidSignature bool) (*SteamAppTicket, error)
*
*
* @param {[]byte} ticket - The raw encrypted ticket
* @param {bool} allowInvalidSignature - Whether to error on tickets with invalid signatures
* @returns {SteamAppTicket}
func ParseEncryptedAppTicket ¶
func ParseEncryptedAppTicket(ticket []byte, key []byte) (*SteamAppTicket, error)
*
*
* @param {[]byte} ticket - The raw encrypted ticket
* @param {[]byte|string} encryptionKey - The raw encryption key
* @returns {SteamAppTicket}
type SteamAppTicketError ¶
type SteamAppTicketError struct {
Message string
}
func (*SteamAppTicketError) Error ¶
func (e *SteamAppTicketError) Error() string
Click to show internal directories.
Click to hide internal directories.